OC.L10N.register(
    "core",
    {
    "Please select a file." : "Selecteer een bestand.",
    "File is too big" : "Bestand te groot",
    "The selected file is not an image." : "Het geselecteerde bestand is geen afbeelding.",
    "The selected file cannot be read." : "Het geselecteerde bestand kan niet worden gelezen.",
    "The file was uploaded" : "Het bestand werd geüpload",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Het geüploade bestand overschrijdt de upload_max_filesize optie in php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Het bestand overschrijdt de MAX_FILE_SIZE waarde die is opgegeven in het HTML formulier",
    "The file was only partially uploaded" : "Het bestand is slechts gedeeltelijk geüpload",
    "No file was uploaded" : "Er is geen bestand geüpload",
    "Missing a temporary folder" : "Tijdelijke map ontbreekt",
    "Could not write file to disk" : "Kon bestand niet naar schijf schrijven",
    "A PHP extension stopped the file upload" : "Een PHP-extensie blokkeerde de upload.",
    "Invalid file provided" : "Ongeldig bestand opgegeven",
    "No image or file provided" : "Geen afbeelding of bestand opgegeven",
    "Unknown filetype" : "Bestandsformaat onbekend",
    "An error occurred. Please contact your admin." : "Er trad een fout op. Neem contact op met je beheerder.",
    "Invalid image" : "Afbeelding ongeldig",
    "No temporary profile picture available, try again" : "Geen tijdelijke profielafbeelding beschikbaar. Probeer het opnieuw",
    "No crop data provided" : "Geen bijsnijdingsgegevens opgegeven",
    "No valid crop data provided" : "Geen geldige bijsnijdingsgegevens opgegeven",
    "Crop is not square" : "Bijgesneden afbeelding is niet vierkant",
    "State token does not match" : "State-token komt niet overeen",
    "Invalid app password" : "Ongeldig appwachtwoord",
    "Could not complete login" : "De login kon niet worden voltooid",
    "Your login token is invalid or has expired" : "Je inlogtoken is ongeldig of is vervallen",
    "This community release of Nextcloud is unsupported and push notifications are limited." : "Deze community release van Nextcloud wordt niet ondersteund en meldingen zijn beperkt",
    "Login" : "Inloggen",
    "Password reset is disabled" : "Wachtwoordreset is uitgeschakeld",
    "Could not reset password because the token is expired" : "Kon wachtwoord niet resetten omdat de token verlopen is",
    "Could not reset password because the token is invalid" : "Kon wachtwoord niet resetten omdat de token ongeldig is",
    "%s password reset" : "%s reset wachtwoord",
    "Password reset" : "Wachtwoordreset",
    "Click the following button to reset your password. If you have not requested the password reset, then ignore this email." : "Klik op de volgende knop om je wachtwoord te resetten. Als je geen wachtwoordreset hebt aangevraagd, negeer dan dit e-mailbericht.",
    "Click the following link to reset your password. If you have not requested the password reset, then ignore this email." : "Klik op de volgende link om je wachtwoord te resetten. Als je geen wachtwoordherstel hebt aangevraagd, negeer dan dit e-mailbericht.",
    "Reset your password" : "Reset je wachtwoord",
    "Nextcloud Server" : "Nextcloud Server",
    "Some of your link shares have been removed" : "Sommige van je gedeelde links zijn verwijderd",
    "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "Door een security-bug moesten we sommige van je gedeelde links verwijderen. Bekijk de link voor meer informatie.",
    "The user limit of this instance is reached." : "De limiet van het aantal gebruikers op deze server is bereikt.",
    "Learn more ↗" : "Meer weten",
    "Preparing update" : "Update voorbereiden",
    "[%d / %d]: %s" : "[%d / %d]: %s",
    "Repair step:" : "Herstel stap:",
    "Repair info:" : "Herstel informatie:",
    "Repair warning:" : "Herstel waarschuwing:",
    "Repair error:" : "Herstel fout:",
    "Please use the command line updater because automatic updating is disabled in the config.php." : "Gebruik de commandoregel updater, omdat automatische update is uitgeschakeld in config.php.",
    "Turned on maintenance mode" : "Onderhoudsmodus ingeschakeld",
    "Turned off maintenance mode" : "Onderhoudsmodus uitgeschakeld",
    "Maintenance mode is kept active" : "Onderhoudsmodus blijft actief",
    "Updating database schema" : "Databaseschema aan het bijwerken",
    "Updated database" : "Database bijgewerkt",
    "Update app \"%s\" from App Store" : "Update app \"%s\" vanuit de App Store",
    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "Controleert of het databaseschema voor %s geüpdatet kan worden (dit kan lang duren afhankelijk van de grootte van de database)",
    "Updated \"%1$s\" to %2$s" : "Werkte \"%1$s\" bij tot %2$s",
    "Set log level to debug" : "Debug logniveau instellen",
    "Reset log level" : "Terugzetten logniveau",
    "Starting code integrity check" : "Starten code betrouwbaarheidscontrole",
    "Finished code integrity check" : "Code betrouwbaarheidscontrole beeindigd",
    "%s (incompatible)" : "%s (incompatibel)",
    "The following apps have been disabled: %s" : "De volgende apps zijn uitgeschakeld: %s",
    "Already up to date" : "Al bijgewerkt",
    "Your web server is not yet properly set up to allow file synchronization, because the WebDAV interface seems to be broken." : "Je webserver is nog niet goed ingesteld voor bestandssynchronisatie, omdat de WebDAV interface niet goed lijkt te werken.",
    "Your web server is not properly set up to resolve \"{url}\". Further information can be found in the {linkstart}documentation ↗{linkend}." : "Je webserver is niet goed ingesteld om \"{url}\" te vinden. Meer informatie is te vinden in onze {linkstart}documentatie↗{linkend}.",
    "Your web server is not properly set up to resolve \"{url}\". This is most likely related to a web server configuration that was not updated to deliver this folder directly. Please compare your configuration against the shipped rewrite rules in \".htaccess\" for Apache or the provided one in the documentation for Nginx at it's {linkstart}documentation page ↗{linkend}. On Nginx those are typically the lines starting with \"location ~\" that need an update." : "Je webserver is niet juist ingesteld voor het verwerken van \"{url}\". De oorzaak ligt waarschijnlijk bij de webserver configuratie die niet bijgewerkt is om deze map rechtstreeks beschikbaar te stellen. Vergelijk je configuratie tegen de installatieversie van de rewrite regels die je vindt in de \".htaccess\" bestanden voor Apache of met de voorbeelden in de documentatie voor Nginx die je vindt op de {linkstart}documentatie pagina↗{linkend}. Op Nginx beginnen deze regels meestal met \"location ~\" die je moet aanpassen.",
    "Your web server is not properly set up to deliver .woff2 files. This is typically an issue with the Nginx configuration. For Nextcloud 15 it needs an adjustement to also deliver .woff2 files. Compare your Nginx configuration to the recommended configuration in our {linkstart}documentation ↗{linkend}." : "Je webserver is niet goed ingesteld om .woff2 bestanden af te leveren. Dit is meestal een probleem met de Nginx configuratie. Voor Nextcloud 15 moet die worden aangepast om ook .woff2 bestanden aan te kunnen. vergelijk jouw Nginx configuratie met de aanbevolen instellingen in onze {linkstart}documentatie ↗{linkend}.",
    "PHP does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "PHP lijkt niet goed te zijn ingesteld voor opvragen systeemomgevingsvariabelen. De test met getenv(\"PATH\") gaf een leeg resultaat.",
    "Please check the {linkstart}installation documentation ↗{linkend} for PHP configuration notes and the PHP configuration of your server, especially when using php-fpm." : "Lees de {linkstart}installatiedocumentatie ↗{linkend} voor php configuratienotities en de php configuratie van je server, zeker bij gebruik van php-fpm.",
    "The read-only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "De alleen-lezen config is ingeschakeld. Dit voorkomt het via de webinterface wijzigen van verschillende instellingen. Bovendien moet het bestand voor elke aanpassing handmatig op beschrijfbaar worden ingesteld.",
    "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "Je database draait niet met \"READ COMMITTED\" transactie-isolatie niveau. Dit kan problemen opleveren als er meerdere acties tegelijkertijd worden uitgevoerd.",
    "The PHP module \"fileinfo\" is missing. It is strongly recommended to enable this module to get the best results with MIME type detection." : "De PHP module \"fileinfo\" ontbreekt. We adviseren met klem om deze module te activeren om de beste resultaten te bereiken voor MIME-type detectie.",
    "Transactional file locking is disabled, this might lead to issues with race conditions. Enable \"filelocking.enabled\" in config.php to avoid these problems. See the {linkstart}documentation ↗{linkend} for more information." : "Transactionele bestandlocking is gedeactiveerd, dat zou kunnen leiden tot versiebeheerproblemen. Schakel \"filelocking enabled\" in config.php in om deze problemen te voorkomen. Zie de {linkstart}documentatie ↗{linkend}  voor meer informatie.",
    "Please make sure to set the \"overwrite.cli.url\" option in your config.php file to the URL that your users mainly use to access this Nextcloud. Suggestion: \"{suggestedOverwriteCliURL}\". Otherwise there might be problems with the URL generation via cron. (It is possible though that the suggested URL is not the URL that your users mainly use to access this Nextcloud. Best is to double check this in any case.)" : "Zorg ervoor dat de optie \"overwrite.cli.url\" in het config.php-bestand is ingesteld op de URL die je gebruikers voornamelijk gebruiken om toegang te krijgen tot deze Nextcloud. Suggestie: \"{suggestedOverwriteCliURL}\". Anders kunnen er problemen zijn met het genereren van URL's via cron. (Het is echter mogelijk dat de voorgestelde URL niet de URL is die je gebruikers voornamelijk gebruiken om toegang te krijgen tot deze Nextcloud. Het beste is om dit in ieder geval dubbel te controleren.)",
    "Your installation has no default phone region set. This is required to validate phone numbers in the profile settings without a country code. To allow numbers without a country code, please add \"default_phone_region\" with the respective {linkstart}ISO 3166-1 code ↗{linkend} of the region to your config file." : "Je installatie heeft geen standaard telefoonregio. Dit is nodig om telefoonnummers te valideren in de profielinstellingen zonder landcode. Om nummers zonder landcode toe te staan, voeg je \"default_phone_region\" met de respectieve {linkstart} ISO 3166-1-code ↗ {linkend} van de regio toe aan je configuratiebestand.",
    "It was not possible to execute the cron job via CLI. The following technical errors have appeared:" : "Het was niet mogelijk om de systeem cron via CLI uit te voeren. De volgende technische problemen traden op:",
    "Last background job execution ran {relativeTime}. Something seems wrong. {linkstart}Check the background job settings ↗{linkend}." : "Laatst uitgevoerde achtergrondtaak {relativeTime}.  Er lijkt iets fout gegaan. {linkstart}Controleer de achtergrond job instellingen ↗{linkend}.",
    "This server has no working internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the internet to enjoy all features." : "Deze server heeft geen werkende internetverbinding: meerdere endpoints kunnen niet worden bereikt. Dat betekent dat sommige functies, zoals het gebruik van externe opslag, notificaties over updates of installatie van apps van derde partijen niet werken. Ook het benaderen van bestanden vanaf een remote locatie en het versturen van notificatie emails kan mislukken. We adviseren om de internetverbinding voor deze server in te schakelen als je alle functies wilt gebruiken.",
    "No memory cache has been configured. To enhance performance, please configure a memcache, if available. Further information can be found in the {linkstart}documentation ↗{linkend}." : "Er is geen geheugencache geconfigureerd. Om de prestaties te verhogen kun je de memcache configureren als die beschikbaar is. Meer informatie vind je in onze {linkstart}documentatie ↗{linkend}.",
    "No suitable source for randomness found by PHP which is highly discouraged for security reasons. Further information can be found in the {linkstart}documentation ↗{linkend}." : "Geen bruikbare bron voor willekeurige waarden gevonden door PHP, hetgeen sterk wordt aanbevolen om beveiligingsredenen. Meer informatie in de {linkstart}documentatie↗{linkend}.",
    "You are currently running PHP {version}. Upgrade your PHP version to take advantage of {linkstart}performance and security updates provided by the PHP Group ↗{linkend} as soon as your distribution supports it." : "Je draait momenteel PHP {version}. We adviseren je om, zo gauw je distributie dat biedt, je PHP versie bij te werken voor betere  {linkstart}prestaties en beveiliging geleverd door de PHP Group↗{linkend}.",
    "Nextcloud 23 is the last release supporting PHP 7.3. Nextcloud 24 requires at least PHP 7.4." : "Nextcloud 23 is de laatste release die PHP 7.3 ondersteund. Nextcloud 24 vereist minstens PHP 7.4.",
    "The reverse proxy header configuration is incorrect, or you are accessing Nextcloud from a trusted proxy. If not, this is a security issue and can allow an attacker to spoof their IP address as visible to the Nextcloud. Further information can be found in the {linkstart}documentation ↗{linkend}." : "De reverse proxy headerconfiguratie is onjuist, of je hebt toegang tot Nextcloud via een vertrouwde proxy. Als je Nextcloud niet via een vertrouwde proxy benadert, dan levert dat een beveiligingsrisico op, waardoor een aanvaller het IP-adres dat Nextcloud ziet kan vervalsen. Meer informatie is te vinden in onze  {linkstart}documentatie ↗{linkend}..",
    "Memcached is configured as distributed cache, but the wrong PHP module \"memcache\" is installed. \\OC\\Memcache\\Memcached only supports \"memcached\" and not \"memcache\". See the {linkstart}memcached wiki about both modules ↗{linkend}." : "Memcached is geconfigureerd als gedistribueerde cache, maar de verkeerde PHP-module \"memcache\" is geïnstalleerd. \\OC\\Memcache\\Memcached ondersteunt alleen \"memcached\" en niet \"memcache\". Zie de {linkstart}memcached wiki over beide modules ↗ {linkend}.",
    "Some files have not passed the integrity check. Further information on how to resolve this issue can be found in the {linkstart1}documentation ↗{linkend}. ({linkstart2}List of invalid files…{linkend} / {linkstart3}Rescan…{linkend})" : "Sommige bestanden hebben de integriteitscontrole niet doorstaan. Meer informatie over het oplossen van dit probleem is te vinden in de {linkstart1} documentatie ↗ {linkend}. ({linkstart2} Lijst met ongeldige bestanden… {linkend} / {linkstart3} Opnieuw scannen… {linkend})",
    "The PHP OPcache module is not properly configured. See the {linkstart}documentation ↗{linkend} for more information." : "De PHP OPcache-module is niet correct geconfigureerd. Zie de {linkstart}documentatie ↗{linkend} voor meer informatie.",
    "The PHP function \"set_time_limit\" is not available. This could result in scripts being halted mid-execution, breaking your installation. Enabling this function is strongly recommended." : "De PHP functie \"set_time_limit\" is niet beschikbaar. Dit kan erin resulteren dat de scripts halverwege stoppen, waardoor de installatie ontregeld raakt. We adviseren sterk om deze functie in te schakelen.",
    "Your PHP does not have FreeType support, resulting in breakage of profile pictures and the settings interface." : "Je PHP heeft geen FreeType ondersteuning. Dit zal leiden tot verminkte profielafbeeldingen en instellingeninterface.",
    "Missing index \"{indexName}\" in table \"{tableName}\"." : "Ontbrekende index \"{indexName}\" in tabel \"{tableName}\".",
    "The database is missing some indexes. Due to the fact that adding indexes on big tables could take some time they were not added automatically. By running \"occ db:add-missing-indices\" those missing indexes could be added manually while the instance keeps running. Once the indexes are added queries to those tables are usually much faster." : "De database mist een paar indexen. Omdat het toevoegen van indexen op grote tabellen veel tijd kan kosten, zijn ze niet automatisch gecreëerd. Door het draaien van \"occ db:add-missing-indices\" kunnen deze indexen handmatig worden toegevoegd terwijl de server blijft draaien.  Als de indexen zijn toegevoegd, zullen opvragingen op die tabellen veel sneller plaatsvinden.",
    "Missing primary key on table \"{tableName}\"." : "Ontbrekende primaire sleutel voor tabel \"{tableName}\".",
    "The database is missing some primary keys. Due to the fact that adding primary keys on big tables could take some time they were not added automatically. By running \"occ db:add-missing-primary-keys\" those missing primary keys could be added manually while the instance keeps running." : "De database mist enkele primaire sleutels. Omdat het toevoegen van primaire sleutels aan grote tabellen enige tijd kan duren, werden ze niet automatisch toegevoegd. Door \"occ db:add-missing-primary-keys\" uit te voeren, kunnen die ontbrekende primaire sleutels handmatig worden toegevoegd terwijl de server blijft draaien.",
    "Missing optional column \"{columnName}\" in table \"{tableName}\"." : "Ontbrekende kolom \"{columnName}\" in tabel \"{tableName}\".",
    "The database is missing some optional columns. Due to the fact that adding columns on big tables could take some time they were not added automatically when they can be optional. By running \"occ db:add-missing-columns\" those missing columns could be added manually while the instance keeps running. Once the columns are added some features might improve responsiveness or usability." : "De database mist een paar optionele kolommen. Omdat het toevoegen van kolommen op grote tabellen veel tijd kan kosten, zijn ze niet automatisch gecreëerd, omdat dat optioneel kan. Door het draaien van \"occ db:add-missing-columns\" kunnen deze kolommen handmatig worden toegevoegd terwijl de server blijft draaien.  Als de kolommen zijn toegevoegd, zullen bepaalde functionaliteiten veel sneller of gemakkelijker plaatsvinden.",
    "This instance is missing some recommended PHP modules. For improved performance and better compatibility it is highly recommended to install them." : "Deze server mist een paar aanbevolen PHP-modules. Voor betere prestaties en compatibiliteit adviseren we om die te installeren.",
    "The PHP module \"imagick\" is not enabled although the theming app is. For favicon generation to work correctly, you need to install and enable this module." : "De PHP-module \"imagick\" is niet ingeschakeld, hoewel de thema-app dat wel is. Om ervoor te zorgen dat het genereren van favicons correct werkt, moet je deze module installeren en inschakelen.",
    "The PHP modules \"gmp\" and/or \"bcmath\" are not enabled. If you use WebAuthn passwordless authentication, these modules are required." : "De PHP-modules \"gmp\" en/of \"bcmath\" zijn niet ingeschakeld. Als je WebAuthn-verificatie zonder wachtwoord gebruikt, zijn deze modules vereist.",
    "Module php-imagick in this instance has no SVG support. For better compatibility it is recommended to install it." : "Module php-imagick op deze server heeft geen SVG-ondersteuning. Voor een betere compatibiliteit wordt aanbevolen om die te installeren.",
    "Some columns in the database are missing a conversion to big int. Due to the fact that changing column types on big tables could take some time they were not changed automatically. By running \"occ db:convert-filecache-bigint\" those pending changes could be applied manually. This operation needs to be made while the instance is offline. For further details read {linkstart}the documentation page about this ↗{linkend}." : "Sommige kolommen in de database zijn niet geconverteerd naar 'big int'. Doordat het wijzigen van kolomtype op grote databases veel tijd kost, zijn ze niet automatisch gewijzigd. Door het uitvoeren van \"occ db:convert-filecache-bigint\" worden de veranderingen alsnog uitgevoerd. Dat moet gebeuren als de server off-line staat. Voor meer informatie verwijzen we naar {linkstart}de documentatie hierover ↗{linkend}.",
    "SQLite is currently being used as the backend database. For larger installations we recommend that you switch to a different database backend." : "SQLite wordt momenteel gebruikt als backend database. Voor grotere installaties adviseren we dat je omschakelt naar een andere database backend.",
    "This is particularly recommended when using the desktop client for file synchronisation." : "Dit wordt vooral aanbevolen als de desktop client wordt gebruikt voor bestandssynchronisatie.",
    "To migrate to another database use the command line tool: \"occ db:convert-type\", or see the {linkstart}documentation ↗{linkend}." : "Om te migreren naar een andere database moet u de commandoregel tool gebruiken: \"occ db:convert-type\", of lees de {linkstart} documentatie  ↗{linkend}.",
    "The PHP memory limit is below the recommended value of 512MB." : "De PHP geheugenlimiet is onder de aanbevolen waarde van 512MB.",
    "Some app directories are owned by a different user than the web server one. This may be the case if apps have been installed manually. Check the permissions of the following app directories:" : "Sommige app directories zijn eigendom van een andere gebruiker dan de webserver . Dat kan het geval zijn als apps handmatig zijn geïnstalleerd. Controleer de machtigingen van de volgende app directories:",
    "MySQL is used as database but does not support 4-byte characters. To be able to handle 4-byte characters (like emojis) without issues in filenames or comments for example it is recommended to enable the 4-byte support in MySQL. For further details read {linkstart}the documentation page about this ↗{linkend}." : "MySQL is in gebruik als database maar deze ondersteunt geen lettertekens van 4 bytes. Om 4-byte lettertekens te ondersteunen (bv. voor emojis) zonder dat dit problemen veroorzaakt bij bestandsnamen of commentaren enz. is het aangeraden om 4-byte letterteken ondersteuning in MySQL te activeren. Voor meer details {linkstart}lees de documentatie hierover ↗{linkend}.",
    "This instance uses an S3 based object store as primary storage. The uploaded files are stored temporarily on the server and thus it is recommended to have 50 GB of free space available in the temp directory of PHP. Check the logs for full details about the path and the available space. To improve this please change the temporary directory in the php.ini or make more space available in that path." : "Deze installatie gebruikt een S3-gebaseerde object opslag als primaire opslag. De geüploade bestanden worden tijdelijk op de server opgeslagen en daarom is het aangeraden om minimaal 50GB vrije ruimte in de temp directory van PHP te hebben. Controleer de logs voor de complete details van het pad en de beschikbare ruimte. Om dit te verbeteren, verander de tijdelijke directory in php.ini of maak meer ruimte beschikbaar in het genoemde pad.",
    "The temporary directory of this instance points to an either non-existing or non-writable directory." : "De tijdelijke map van deze instantie verwijst naar een niet bestaande of niet beschrijfbare map.",
    "You are accessing your instance over a secure connection, however your instance is generating insecure URLs. This most likely means that you are behind a reverse proxy and the overwrite config variables are not set correctly. Please read {linkstart}the documentation page about this ↗{linkend}." : "Je verbindt met je server over een beveiligd kanaal, maar je server genereert onveilige URLs. Waarschijnlijk zit je achter een reverse proxy en zijn de overschijf config variabelen niet goed ingesteld. Lees [linkstart]de documentatie hierover ↗{linkend}.",
    "Error occurred while checking server setup" : "Een fout trad op bij controleren van serverconfiguratie",
    "For more details see the {linkstart}documentation ↗{linkend}." : "Voor meer informatie word je verwezen naar de {linkstart}documentatie↗{linkend}.",
    "Your data directory and files are probably accessible from the internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root." : "Je datamap en je bestanden zijn waarschijnlijk vanaf het internet bereikbaar.  Het .htaccess-bestand werkt niet. We raden ten zeerste aan aan om je webserver zodanig te configureren, dat de datadirectory niet bereikbaar is vanaf het internet of om je datadirectory te verplaatsen naar een locatie buiten de document-root van de webserver.",
    "The \"{header}\" HTTP header is not set to \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "De \"{header}\" HTTP header is niet ingesteld als \"{expected}\". Dit is een potentieel security of privacy risico en we adviseren om deze instelling te wijzigen.",
    "The \"{header}\" HTTP header is not set to \"{expected}\". Some features might not work correctly, as it is recommended to adjust this setting accordingly." : "De \"{header}\" HTTP header is ingesteld als \"{expected}\". Sommige functies werken mogelijk niet zoals bedoeld en we adviseren om deze instelling te wijzigen.",
    "The \"{header}\" HTTP header is not set to \"{val1}\", \"{val2}\", \"{val3}\", \"{val4}\" or \"{val5}\". This can leak referer information. See the {linkstart}W3C Recommendation ↗{linkend}." : "De \"{header}\" HTTP header is niet ingesteld op \"{val1}\", \"{val2}\", \"{val3}\", \"{val4}\" of \"{val5}\". Hierdoor kan verwijzingsinformatie uitlekken. Zie de {linkstart}W3C aanbeveling ↗{linkend}.",
    "The \"Strict-Transport-Security\" HTTP header is not set to at least \"{seconds}\" seconds. For enhanced security, it is recommended to enable HSTS as described in the {linkstart}security tips ↗{linkend}." : "De \"Strict-Transport-Security\" HTTP header is niet ingesteld als minimaal \"{seconds}\" seconden. Voor verbeterde beveiliging adviseren we HSTS in te schakelen zoals beschreven in de {linkstart}security tips ↗{linkend}.",
    "Accessing site insecurely via HTTP. You are strongly advised to set up your server to require HTTPS instead, as described in the {linkstart}security tips ↗{linkend}." : "De site is onveilig verbonden over HTTP. We adviseren je dringend om je server zo te configureren dat HTTPS wordt vereist, zoals beschreven in de {linkstart}security tips ↗{linkend}.",
    "unknown text" : "onbekende tekst",
    "Hello world!" : "Hallo wereld!",
    "sunny" : "zonnig",
    "Hello {name}, the weather is {weather}" : "Hallo {name}, het is hier {weather}",
    "Hello {name}" : "Hallo {name}",
    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Dit zijn je zoekresultaten<script>alert(1)</script></strong>",
    "new" : "nieuw",
    "_download %n file_::_download %n files_" : ["download %n bestand","download %n bestanden"],
    "The update is in progress, leaving this page might interrupt the process in some environments." : "De update is bezig, deze pagina verlaten kan het updateproces in sommige omgevingen onderbreken.",
    "Update to {version}" : "Geüpdatet naar {version}",
    "An error occurred." : "Er heeft zich een fout voorgedaan.",
    "Please reload the page." : "Herlaad deze pagina.",
    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "De update was niet succesvol. Voor meer informatie <a href=\"{url}\">zie ons bericht op het forum</a> over dit probleem.",
    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "De update is mislukt. Meld dit probleem aan de <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>.",
    "Continue to {productName}" : "Verder naar {productName}",
    "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["De update was succesvol. Redirecten naar {productName} over %nseconde.","De update was succesvol. Redirecten naar {productName} over %n seconden."],
    "More apps" : "Meer apps",
    "Currently open" : "Momenteel actief",
    "_{count} notification_::_{count} notifications_" : ["{count} melding","{count} meldingen"],
    "Log in" : "Inloggen",
    "Logging in …" : "Inloggen...",
    "Server side authentication failed!" : "Authenticatie bij de server mislukt!",
    "Please contact your administrator." : "Neem contact op met je systeembeheerder.",
    "An internal error occurred." : "Er heeft zich een interne fout voorgedaan.",
    "Please try again or contact your administrator." : "Probeer het opnieuw of neem contact op met je beheerder.",
    "Log in to {productName}" : "Aanmelden voor {productName}",
    "Account name or email" : "Gebruikersnaam of email",
    "Password" : "Wachtwoord",
    "Wrong username or password." : "Verkeerde gebruikersnaam of wachtwoord.",
    "User disabled" : "Gebruiker gedeactiveerd",
    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "We hebben meerdere foutieve inlogverzoeken vanaf jouw IP-adres gedetecteerd. Hierdoor wordt je volgende inlogverzoek 30 seconden uitgesteld.",
    "Username or email" : "Gebruikersnaam of email",
    "Your account is not setup for passwordless login." : "Je account is niet ingesteld voor inloggen zonder wachtwoord.",
    "Browser not supported" : "Browser niet ondersteund",
    "Passwordless authentication is not supported in your browser." : "Inloggen zonder wachtwoord is niet ondersteund door je browser.",
    "Your connection is not secure" : "Je verbinding is niet veilig",
    "Passwordless authentication is only available over a secure connection." : "Inloggen zonder wachtwoord is alleen mogelijk over een beveiligde verbinding.",
    "Reset password" : "Reset wachtwoord",
    "A password reset message has been sent to the email address of this account. If you do not receive it, check your spam/junk folders or ask your local administrator for help." : "Er is een wachtwoordherstelbericht verzonden naar het e-mailadres van dit account. Als je het niet hebt ontvangen, controleer dan je spam / ongewenste mappen, of vraag je beheerder om hulp.",
    "If it is not there ask your local administrator." : "Als het hier niet is, vraag dan de lokale beheerder",
    "Couldn't send reset email. Please contact your administrator." : "Kon herstel email niet versturen. Neem contact op met je beheerder.",
    "Password cannot be changed. Please contact your administrator." : "Het wachtwoord kan niet worden gewijzigd. Neem contact op met je beheerder.",
    "Back to login" : "Terug naar inloggen",
    "New password" : "Nieuw wachtwoord",
    "Your files are encrypted. There will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" : "Je bestanden zijn versleuteld. Het is niet mogelijk om je gegevens terug te krijgen als je wachtwoord wordt gereset. Als je niet zeker weer wat je moet doen, neem dan contact op met je beheerder voordat je verdergaat. Wil je echt verder gaan?",
    "I know what I'm doing" : "Ik weet wat ik doe",
    "Resetting password" : "Resetten wachtwoord",
    "Recommended apps" : "Aanbevolen apps",
    "Loading apps …" : "Laden apps ...",
    "Could not fetch list of apps from the App Store." : "Kon lijst met apps niet ophalen vanuit de App Store.",
    "Installing apps …" : "Installeren apps …",
    "App download or installation failed" : "App download of installatie mislukt",
    "Cannot install this app because it is not compatible" : "Kan deze app niet installeren omdat deze niet compatible is",
    "Cannot install this app" : "Kan deze app niet installeren",
    "Skip" : "Overslaan",
    "Install recommended apps" : "Installeer aanbevolen apps",
    "Schedule work & meetings, synced with all your devices." : "Plan je werk & afspraken, gesynced met al je toestellen.",
    "Keep your colleagues and friends in one place without leaking their private info." : "Bewaar je collega's en vrienden op één plaats zonder hun persoonlijke gegevens te laten uitlekken.",
    "Simple email app nicely integrated with Files, Contacts and Calendar." : "Simpele e-mailapp, handig geïntegreerd met Bestanden, Contactpersonen en Agenda.",
    "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Chatten, videobellen, schermdelen, online vergaderingen en webconferenties - in de browser en met mobiele apps.",
    "Forgot password?" : "Wachtwoord vergeten?",
    "Log in with a device" : "Inloggen met een toestel",
    "Back" : "Terug",
    "Login form is disabled." : "Inlogscherm uitgeschakeld",
    "Edit Profile" : "Wijzig Profiel",
    "The headline and about sections will show up here" : "De koplijn- en oversectie zal hier verschijnen",
    "You have not added any info yet" : "Je hebt nog geen info toegevoegd",
    "{user} has not added any info yet" : "{user} heeft nog geen info toegevoegd",
    "Error opening the user status modal, try hard refreshing the page" : "Fout bij het openen van het gebruiker status model, probeer een harde refresh van de pagina",
    "Search starts once you start typing" : "Zoeken begint zodra u iets typt",
    "Reset search" : "Zoekopdracht wissen",
    "Start search" : "Begin met zoeken",
    "Search for {name} only" : "Zoek alleen naar {name}",
    "No results for {query}" : "Geen resultaten voor {query}",
    "Press enter to start searching" : "Druk op Enter om te beginnen zoeken",
    "Start typing to search" : "Begin met typen om te zoeken",
    "Loading more results …" : "Meer resultaten laden ...",
    "Load more results" : "Laad meer resultaten",
    "Search" : "Zoeken",
    "An error occurred while searching for {type}" : "Er trad een fout op bij het zoeken naar {type}",
    "_Please enter {minSearchLength} character or more to search_::_Please enter {minSearchLength} characters or more to search_" : ["Voer {minSearchLength} tekens of meer in om te zoeken","Voer alstublieft {minSearchLength} tekens of meer in om te zoeken"],
    "Search {types} …" : "Zoeken naar {types}…",
    "Settings" : "Instellingen",
    "Could not load your contacts" : "Kon je contactpersonenen niet laden",
    "Search contacts …" : "Zoek contacten ...",
    "No contacts found" : "Geen contacten gevonden",
    "Show all contacts …" : "Alle contacten weergeven",
    "Install the Contacts app" : "Installeer de Contacts app",
    "Loading your contacts …" : "Je contacten wordt geladen ...",
    "Looking for {term} …" : "Kijken voor {term} …",
    "No" : "Nee",
    "Yes" : "Ja",
    "No files in here" : "Hier geen bestanden",
    "New folder" : "Nieuwe map",
    "No more subfolders in here" : "Hier niet meer submappen",
    "Name" : "Naam",
    "Size" : "Grootte",
    "Modified" : "Aangepast",
    "\"{name}\" is an invalid file name." : "\"{name}\" is een ongeldige bestandsnaam.",
    "File name cannot be empty." : "Bestandsnaam kan niet leeg zijn.",
    "\"/\" is not allowed inside a file name." : "\"/\" is niet toegestaan binnen een bestandsnaam.",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" is een niet toegestaan bestandstype",
    "{newName} already exists" : "{newName} bestaat al",
    "Choose" : "Kies",
    "Copy" : "Kopiëren",
    "Move" : "Verplaats",
    "Error loading file picker template: {error}" : "Fout bij laden bestandenselecteur sjabloon: {error}",
    "OK" : "OK",
    "Error loading message template: {error}" : "Fout bij laden berichtensjabloon: {error}",
    "read-only" : "Alleen lezen",
    "_{count} file conflict_::_{count} file conflicts_" : ["{count} bestandsconflict","{count} bestandsconflicten"],
    "One file conflict" : "Een bestandsconflict",
    "New Files" : "Nieuwe bestanden",
    "Already existing files" : "Al aanwezige bestanden",
    "Which files do you want to keep?" : "Welke bestanden wil je bewaren?",
    "If you select both versions, the copied file will have a number added to its name." : "Als je beide versies selecteerde, zal het gekopieerde bestand een nummer aan de naam toegevoegd krijgen.",
    "Cancel" : "Annuleren",
    "Continue" : "Verder",
    "(all selected)" : "(alles geselecteerd)",
    "({count} selected)" : "({count} geselecteerd)",
    "Error loading file exists template" : "Fout bij laden bestand bestaat al sjabloon",
    "Pending" : "Onderhanden",
    "Copy to {folder}" : "Kopieer naar {folder}",
    "Move to {folder}" : "Verplaats naar {folder}",
    "Saving …" : "Opslaan ...",
    "Authentication required" : "Authenticatie vereist",
    "This action requires you to confirm your password" : "Deze actie vereist dat je je wachtwoord bevestigt",
    "Confirm" : "Bevestig",
    "Failed to authenticate, try again" : "Authenticatie mislukt, probeer opnieuw",
    "seconds ago" : "seconden geleden",
    "Connection to server lost" : "Verbinding met server verbroken",
    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Probleem met laden pagina, herladen over %n seconde","Probleem met laden pagina, herladen over %n seconden"],
    "Add to a project" : "Toevoegen aan een project",
    "Show details" : "Bekijk details",
    "Hide details" : "Verberg details",
    "Rename project" : "Hernoem project",
    "Failed to rename the project" : "Hernoemen van project is mislukt",
    "Failed to create a project" : "Aanmaken van project is mislukt",
    "Failed to add the item to the project" : "Item toevoegen aan project mislukt",
    "Connect items to a project to make them easier to find" : "Verbind items aan een project om ze eenvoudiger terug te vinden",
    "Type to search for existing projects" : "Type om bestaande projecten te vinden",
    "New in" : "Nieuw in",
    "View changelog" : "Bekijk wijzigingsoverzicht",
    "Very weak password" : "Zeer zwak wachtwoord",
    "Weak password" : "Zwak wachtwoord",
    "So-so password" : "Matig wachtwoord",
    "Good password" : "Goed wachtwoord",
    "Strong password" : "Sterk wachtwoord",
    "No action available" : "Geen actie beschikbaar",
    "Error fetching contact actions" : "Fout bij ophalen contact acties",
    "Non-existing tag #{tag}" : "Niet bestaande markering #{tag}",
    "Restricted" : "Beperkt",
    "Invisible" : "Onzichtbaar",
    "Delete" : "Verwijder",
    "Rename" : "Naam wijzigen",
    "Collaborative tags" : "Systeemtags",
    "No tags found" : "Geen tags gevonden",
    "Personal" : "Persoonlijk",
    "Users" : "Gebruikers",
    "Apps" : "Apps",
    "Admin" : "Beheerder",
    "Help" : "Help",
    "Access forbidden" : "Toegang verboden",
    "Profile not found" : "Proefiel niet gevonden",
    "The profile does not exist." : "Het profiel bestaat niet.",
    "Back to %s" : "Terug naar %s",
    "Page not found" : "Pagina niet gevonden",
    "Too many requests" : "Te veel aanvragen",
    "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Er waren te veel aanvragen afkomstig uit uw netwerk. Probeer later opnieuw of contacteer de beheerder als dat niet correct is.",
    "Error" : "Fout",
    "Previous" : "Vorige",
    "Internal Server Error" : "Interne serverfout",
    "The server was unable to complete your request." : "De server was niet in staat je aanvraag te verwerken.",
    "If this happens again, please send the technical details below to the server administrator." : "Stuur de hieronder afgebeelde technische details naar de serverbeheerder wanneer dit opnieuw gebeurt.",
    "More details can be found in the server log." : "Meer details in de serverlogging,",
    "Technical details" : "Technische details",
    "Remote Address: %s" : "Extern adres: %s",
    "Request ID: %s" : "Aanvraag ID: %s",
    "Type: %s" : "Type: %s",
    "Code: %s" : "Code: %s",
    "Message: %s" : "Boodschap: %s",
    "File: %s" : "Bestand: %s",
    "Line: %s" : "Regel: %s",
    "Trace" : "Trace",
    "Security warning" : "Beveiligingswaarschuwing",
    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Je gegevensdirectory en bestanden zijn vermoedelijk bereikbaar vanaf het internet, omdat het .htaccess-bestand niet functioneert.",
    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Bekijk de <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentatie</a> voor Informatie over het correct configureren van je server.",
    "Create an <strong>admin account</strong>" : "Maak een <strong>beheerdersaccount</strong> aan",
    "Username" : "Gebruikersnaam",
    "Show password" : "Toon wachtwoord",
    "Toggle password visibility" : "Omschakelen zichtbaarheid wachtwoord",
    "Storage & database" : "Opslag & database",
    "Data folder" : "Gegevensmap",
    "Configure the database" : "Configureer de database",
    "Only %s is available." : "Alleen %s is beschikbaar.",
    "Install and activate additional PHP modules to choose other database types." : "Installeer en activeer aanvullende PHP modules om andere soorten databases te kiezen.",
    "For more details check out the documentation." : "Voor meer informatie word je verwezen naar de documentatie.",
    "Database user" : "Gebruiker database",
    "Database password" : "Wachtwoord database",
    "Database name" : "Naam database",
    "Database tablespace" : "Database tablespace",
    "Database host" : "Databaseserver",
    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Geef het poortnummer en servernaam op (bijv. localhost:5432).",
    "Performance warning" : "Prestatiewaarschuwing",
    "You chose SQLite as database." : "Je koos SQLite als database.",
    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite zou alleen moeten worden gebruikt voor minimale en ontwikkelomgevingen. Voor productie raden we aan om een andere database backend te gebruiken.",
    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Als je clients gebruikt voor bestandssynchronisatie wordt het gebruik van SQLite sterk ontraden.",
    "Install" : "Installeren",
    "Installing …" : "Installeren …",
    "Need help?" : "Hulp nodig?",
    "See the documentation" : "Zie de documentatie",
    "It looks like you are trying to reinstall your Nextcloud. However the file CAN_INSTALL is missing from your config directory. Please create the file CAN_INSTALL in your config folder to continue." : "Het lijkt erop of je Nextcloud wilt herinstalleren. Maar het bestand CAN_INSTALL ontbreekt in de configdirectory. Maak het bestand CAN_INSTALL aan in je config map om verder te gaan.",
    "Could not remove CAN_INSTALL from the config folder. Please remove this file manually." : "Kon CAN_INSTALL niet verwijderen uit de config map. Verwijder het bestand handmatig.",
    "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Deze applicatie heeft JavaScript nodig. {linkstart}Activeer JavaScript{linkend} en ververs deze pagina.",
    "Skip to main content" : "Ga naar hoofdinhoud",
    "Skip to navigation of app" : "Ga naar navigatie van app",
    "Get your own free account" : "Maak je eigen gratis account",
    "%s's homepage" : "%s's homepage",
    "Contacts" : "Contactpersonen",
    "Contacts menu" : "Contacten menu",
    "Confirm your password" : "Bevestig je wachtwoord",
    "Connect to your account" : "Verbind jouw account",
    "Please log in before granting %1$s access to your %2$s account." : "Eerst inloggen voordat je %1$s toegang geeft tot je %2$s account.",
    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Als u geen nieuw apparaat of nieuwe app probeert in te stellen, probeert iemand je te misleiden om hem toegang tot je gegevens te verlenen. Ga in dat geval niet verder en neem in plaats daarvan contact op met je systeembeheerder.",
    "App token" : "App token",
    "Grant access" : "Verleen toegang",
    "Alternative log in using app token" : "Alternatief aanmelden met app token",
    "Account access" : "Account toegang",
    "You are about to grant %1$s access to your %2$s account." : "Je staat op het punt om %1$s toegang te verlenen tot je %2$s account.",
    "Account connected" : "Account verbonden",
    "Your client should now be connected!" : "Je client zou nu moeten verbonden zijn!",
    "You can close this window." : "Je mag dit venster sluiten.",
    "This share is password-protected" : "Deze share is wachtwoordbeveiligd",
    "The password is wrong or expired. Please try again or request a new one." : "Het paswoord is fout of vervallen. Probeer opnieuw of vraag er een nieuw aan.",
    "Email address" : "E-mailadres",
    "Password sent!" : "Wachtwoord verzonden!",
    "Go to %s" : "Ga naar %s",
    "Two-factor authentication" : "Tweefactor authenticatie",
    "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "Versterkte beveiliging is ingeschakeld voor je account. Kies een tweede factor voor authenticatie:",
    "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "Kon niet minimaal één van je ingeschakelde twee-factor auth methoden laden. Neem contact op met je beheerder.",
    "Two-factor authentication is enforced but has not been configured on your account. Contact your admin for assistance." : "Tweefactor authenticatie is ingeschakeld, maar niet geconfigureerd voor je account. Neem voor hulp contact op met je beheerder.",
    "Two-factor authentication is enforced but has not been configured on your account. Please continue to setup two-factor authentication." : "Tweefactor authenticatie is ingeschakeld, maar niet geconfigureerd voor je account. Ga verder met instellen van tweefactor authenticatie.",
    "Set up two-factor authentication" : "Instellen tweefactor authenticatie",
    "Two-factor authentication is enforced but has not been configured on your account. Use one of your backup codes to log in or contact your admin for assistance." : "Tweefactor authenticatie is ingeschakeld, maar niet geconfigureerd voor je account. Gebruik een van je backup codes om in te loggen of neem voor hulp contact op met je beheerder.",
    "Use backup code" : "Gebruik back-upcode",
    "Cancel login" : "Inlog annuleren",
    "Enhanced security is enforced for your account. Choose which provider to set up:" : "Versterkte beveiliging is ingeschakeld voor je account. Kies een provider om in te stellen:",
    "Error while validating your second factor" : "Fout bij het verifiëren van je tweede factor",
    "Access through untrusted domain" : "Toegang via een niet vertrouwd domein",
    "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "Neem contact op met je beheerder. Wanneer je een beheerder bent kun je de \"trusted_domains\" instelling bewerken in config/config.php zoals in het voorbeeld config.sample.php. ",
    "Further information how to configure this can be found in the %1$sdocumentation%2$s." : "Verdere informatie over hoe je dit instelt staat in de %1$s documentatie  %2$s.",
    "App update required" : "Bijwerken App vereist",
    "%1$s will be updated to version %2$s" : "%1$s wordt geüpdatet naar versie %2$s",
    "The following apps will be updated:" : "Deze apps worden bijgewerkt:",
    "These incompatible apps will be disabled:" : "De volgende incompatibele apps worden uitgeschakeld:",
    "The theme %s has been disabled." : "Het thema %s is uitgeschakeld.",
    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Let erop dat de database, de config-map en de data-map zijn geback-upt voordat je verder gaat.",
    "Start update" : "Begin de update",
    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Om time-outs tijdens grotere installaties te voorkomen, kun je in plaats hiervan de volgende opdracht geven vanaf je installatiedirectory:",
    "Detailed logs" : "Gedetailleerde logs",
    "Update needed" : "Update vereist",
    "Please use the command line updater because you have a big instance with more than 50 users." : "Gebruik alsjeblieft de commandoregel updater omdat je een installatie hebt met meer dan 50 gebruikers.",
    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "Bekijk de <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentatie</a> voor hulp.",
    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "De update via de web UI heeft risico's. Het verzoek leidt mogelijk tot een time-out en kan tot verlies van gegevens leiden. Ik heb een back-up gemaakt en weet hoe deze te herstellen in het geval van een update mislukking.",
    "Upgrade via web on my own risk" : "Web opwaarding is op eigen risico",
    "Maintenance mode" : "Onderhoudsmodus",
    "This %s instance is currently in maintenance mode, which may take a while." : "Deze %s staat momenteel in de onderhoudsstand, dat kan enige tijd duren.",
    "This page will refresh itself when the instance is available again." : "Deze pagina wordt ververst als de server weer beschikbaar is.",
    "Contact your system administrator if this message persists or appeared unexpectedly." : "Neem contact op met je systeembeheerder als deze melding aanhoudt of onverwacht verscheen.",
    "Enter your subscription key to increase the user limit. For more information about Nextcloud Enterprise see our website." : "Voer je abonnementssleutel in om de gebruikerslimiet te verhogen. Zie onze website voor meer informatie over Nextcloud Enterprise.",
    "[%d / %d]: Checking table %s" : "[%d / %d]: Tabel controleren %s",
    "This server has no working Internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the Internet to enjoy all features." : "Deze server heeft geen werkende internetverbinding: meerdere endpoints kunnen niet worden bereikt. Dat betekent dat sommige functies, zoals het gebruik van externe opslag, notificaties over updates of installatie van apps van derde partijen niet werken. Ook het benaderen van bestanden vanaf een remote locatie en het versturen van notificatie emails kan mislukken. We adviseren om de internetverbinding voor deze server in te schakelen als je alle functies wilt gebruiken.",
    "Nextcloud 20 is the last release supporting PHP 7.2. Nextcloud 21 requires at least PHP 7.3." : "Nextcloud 20 is de laatste release met ondersteuning voor PHP 7.2. Nextcloud 21 heeft minstens PHP 7.3 nodig.",
    "The PHP OPcache module is not loaded. {linkstart}For better performance it is recommended ↗{linkend} to load it into your PHP installation." : "De PHP OPcache is niet geladen.  {linkstart}Voor betere prestaties  adviseren we ↗{linkend}  die te laden in je php.ini instellingen.",
    "The PHP OPcache module is not properly configured. {linkstart}For better performance it is recommended ↗{linkend} to use the following settings in the <code>php.ini</code>:" : "De PHP OPcache is niet correct geconfigureerd. {linkstart}Voor betere prestaties wordt aanbevolen ↗ {linked} om de volgende instellingen in de <code>php.ini</code> te gebruiken:",
    "Some columns in the database are missing a conversion to big int. Due to the fact that changing column types on big tables could take some time they were not changed automatically. By running 'occ db:convert-filecache-bigint' those pending changes could be applied manually. This operation needs to be made while the instance is offline. For further details read {linkstart}the documentation page about this ↗{linkend}." : "Sommige kolommen in de database zijn niet geconverteerd naar 'big int'. Doordat het wijzigen van kolomtype op grote databases veel tijd kost, zijn ze niet automatisch gewijzigd. Door het uitvoeren van 'occ db:convert-filecache-bigint' worden de veranderingen alsnog uitgevoerd. Dat moet gebeuren als de server off-line staat. Voor meer informatie verwijzen we naar {linkstart}de documentatie hierover ↗{linkend}.",
    "To migrate to another database use the command line tool: 'occ db:convert-type', or see the {linkstart}documentation ↗{linkend}." : "Om te migreren naar een andere database moet u de commandoregel tool gebruiken: 'occ db:convert-type', of lees de {linkstart} documentatie  ↗{linkend}.",
    "Your data directory and files are probably accessible from the Internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root." : "Je datamap en je bestanden zijn waarschijnlijk vanaf het internet bereikbaar.  Het .htaccess-bestand werkt niet. We raden ten zeerste aan aan om je webserver zodanig te configureren, dat de datadirectory niet bereikbaar is vanaf het internet of om je datadirectory te verplaatsen naar een locatie buiten de document-root van de webserver.",
    "The \"{header}\" HTTP header doesn't contain \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "De \"{header}\" HTTP header bevat niet \"{expected}\". Dit is een potentieel security of privacy risico en we adviseren om deze instelling te wijzigen.",
    "Collaboratively edit office documents." : "Bewerk office documenten gezamelijk.",
    "Local document editing back-end used by the Collabora Online app." : "Lokale back-end voor bestandsbewerking gebruikt door de Collabora Online app.",
    "restricted" : "beperkt",
    "invisible" : "onzichtbaar",
    "File not found" : "Bestand niet gevonden",
    "The document could not be found on the server. Maybe the share was deleted or has expired?" : "Het document werd niet gevonden op de server. Misschien is de share verwijderd of verlopen?",
    "More" : "Meer",
    "More apps menu" : "Meer apps menu",
    "Settings menu" : "Instellingenmenu",
    "The password is wrong. Try again." : "Het wachtwoord is onjuist. Probeer opnieuw.",
    "Setup two-factor authentication" : "Instellen tweefactor authenticatie",
    "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "Deze community release van Nextcloud wordt niet ondersteund en instant meldingen zijn niet beschikbaar.",
    "This is the unsupported community build of Nextcloud. Given the size of this instance, performance, reliability and scalability cannot be guaranteed. Push notifications have been disabled to avoid overloading our free service. Learn more about the benefits of Nextcloud Enterprise at nextcloud.com/enterprise." : "Dit is de niet-ondersteunde community build van Nextcloud. Gegeven de grootte van deze instantie kunnen prestaties, betrouwbaarheid en schaalbaarheid niet worden gegarandeerd. Push meldingen zijn uitgeschakeld om te voorkomen dat onze gratis service wordt overbelast. Lees meer over de voordelen van Nextcloud Enterprise op nextcloud.com/enterprise.",
    "You haven't added any info yet" : "Je hebt nog geen info toegevoegd",
    "{user} hasn't added any info yet" : "{user} heeft nog geen info toegevoegd"
},
"nplurals=2; plural=(n != 1);");
